==> buffybox_3.2.0+dfsg.orig.tar.xz: buffybox-3.2.0/lvgl/tests/test_images/stride_align1/LZ4/test_A8_LZ4_align1.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif


#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_IMG_DUST
#define LV_ATTRIBUTE_IMG_DUST
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_IMG_DUST
uint8_t test_A8_LZ4_align1_map[] = {

    0x02,0x00,0x00,0x00,0x6e,0x05,0x00,0x00,0xc0,0x12,0x00,0x00,0x1f,0xff,0x01,0x00,
    0x33,0x14,0x00,0x01,0x00,0x14,0xff,0x09,0x00,0x0f,0x02,0x00,0x2a,0x06,0x46,0x00,
    0x06,0x0a,0x00,0x0f,0x02,0x00,0x29,0x06,0x46,0x00,0x3c,0xff,0x00,0x00,0xf2,0x00,
    0x0f,0x59,0x00,0x0d,0x0c,0x30,0x00,0x11,0xff,0x46,0x00,0x03,0x02,0x00,0x0f,0x50,
    0x00,0x07,0x83,0x3f,0x96,0xd6,0xf9,0xf9,0xd6,0x96,0x3f,0x29,0x00,0x06,0x02,0x00,
    0x06,0x8d,0x00,0x02,0x02,0x00,0x0f,0x50,0x00,0x12,0x24,0x1a,0x93,0x87,0x00,0x22,
    0x93,0x1a,0x37,0x00,0x41,0x6a,0xdf,0xdf,0x6a,0x0a,0x00,0x1a,0xff,0xd2,0x00,0x0f,
    0x50,0x00,0x12,0x24,0x1a,0xa7,0x4f,0x00,0x32,0xff,0xff,0xa7,0x51,0x00,0x44,0xdf,
    0xff,0xff,0xdf,0x50,0x00,0x01,0x08,0x00,0x02,0x02,0x00,0x0f,0x50,0x00,0x13,0x05,
    0x9e,0x00,0x00,0x50,0x02,0x11,0x93,0x3a,0x00,0x09,0x50,0x00,0x02,0x19,0x00,0x02,
    0x9e,0x00,0x0f,0xa0,0x00,0x10,0x11,0x3f,0x2c,0x00,0x05,0x02,0x00,0x01,0x44,0x01,
    0x08,0xf0,0x00,0x05,0xa2,0x00,0x03,0x0c,0x00,0x06,0x53,0x01,0x0f,0x90,0x01,0x03,
    0x15,0x96,0x4b,0x00,0x01,0x02,0x00,0x11,0x96,0xa1,0x00,0x04,0x02,0x00,0x02,0x44,
    0x00,0x01,0x19,0x00,0x01,0x4e,0x00,0x0f,0xa0,0x00,0x10,0x11,0xd6,0x2e,0x00,0x05,
    0x02,0x00,0x14,0xd6,0x4b,0x00,0x01,0x02,0x00,0x03,0x50,0x00,0x08,0x0a,0x00,0x0f,
    0xa0,0x00,0x0d,0x15,0xf9,0x4b,0x00,0x01,0x02,0x00,0xb7,0xf9,0x00,0x00,0x00,0x40,
    0xac,0xf2,0xf2,0xac,0x40,0x00,0x46,0x00,0x06,0x02,0x00,0x01,0x5d,0x00,0x02,0x02,
    0x00,0x0f,0xf0,0x00,0x03,0x0e,0x50,0x00,0x20,0x40,0xd3,0xea,0x03,0x27,0xd3,0x40,
    0x50,0x00,0x0f,0xa0,0x00,0x18,0x0e,0xf0,0x00,0x11,0xac,0xa9,0x00,0x26,0xff,0xac,
    0x50,0x00,0x00,0x4a,0x04,0x0f,0x40,0x01,0x15,0x0e,0x90,0x01,0x12,0xf2,0x50,0x00,
    0x15,0xf2,0x50,0x00,0x04,0xdf,0x00,0x0f,0x90,0x01,0x12,0x0e,0x30,0x02,0x0c,0x50,
    0x00,0x02,0x5f,0x00,0x03,0xa2,0x00,0x0f,0x40,0x01,0x0e,0x0e,0xd0,0x02,0x0b,0xf0,
    0x00,0x02,0x9e,0x00,0x04,0x9e,0x01,0x0f,0x50,0x00,0x0f,0x0d,0x70,0x03,0x0a,0x90,
    0x01,0x04,0x9e,0x00,0x03,0xa2,0x00,0x0f,0x50,0x00,0x0f,0x0e,0x10,0x04,0x08,0x30,
    0x02,0x02,0x9a,0x00,0x04,0x02,0x00,0x0c,0x50,0x00,0x0f,0x02,0x00,0x04,0x0f,0xb0,
    0x04,0x07,0x02,0x98,0x00,0x06,0x02,0x00,0x01,0x53,0x00,0x03,0x02,0x00,0x0c,0x6d,
    0x00,0x0f,0x02,0x00,0x23,0x06,0x46,0x00,0x06,0x0a,0x00,0x0f,0x02,0x00,0x29,0x06,
    0x46,0x00,0x04,0x0a,0x00,0x54,0x12,0x28,0x33,0x26,0x08,0x53,0x00,0x06,0xcb,0x00,
    0x0f,0x02,0x00,0x12,0x06,0x46,0x00,0x03,0x0a,0x00,0x30,0x35,0x95,0xdd,0x38,0x07,
    0x44,0xfa,0xc4,0x5c,0x01,0x53,0x00,0x0f,0x02,0x00,0x1b,0x04,0x96,0x00,0x02,0x0a,
    0x00,0x16,0xb2,0x86,0x00,0x2f,0xbb,0x0b,0x49,0x00,0x1b,0x03,0x02,0x00,0x0a,0x50,
    0x00,0x10,0xe9,0xd5,0x07,0x21,0xfe,0xfa,0x56,0x00,0x13,0xa9,0x22,0x00,0x0f,0x02,
    0x00,0x1b,0x0a,0x50,0x00,0x81,0xe5,0xff,0xff,0xe5,0x49,0x09,0x03,0x3c,0xf5,0x00,
    0x1f,0x2b,0x4a,0x00,0x1b,0x02,0x02,0x00,0x0a,0x50,0x00,0x90,0xe1,0xff,0xff,0xa3,
    0x00,0x00,0x00,0x00,0x44,0x7d,0x08,0x12,0x6f,0x22,0x00,0xa4,0x00,0x00,0x14,0x76,
    0xbb,0xdd,0xe6,0xd3,0x9e,0x37,0x10,0x00,0x0f,0x02,0x00,0x09,0x0a,0x50,0x00,0x90,
    0xbe,0xdc,0xdc,0x6b,0x00,0x00,0x00,0x00,0x09,0xcd,0x08,0x13,0x89,0x38,0x00,0x21,
    0x53,0xf8,0x00,0x01,0x33,0xff,0xfe,0x7b,0x11,0x00,0x0f,0x02,0x00,0x09,0x0a,0x50,
    0x00,0x02,0x02,0x00,0x30,0x0e,0x14,0x14,0x1d,0x09,0x12,0x90,0x0e,0x00,0xbf,0x00,
    0x6c,0xff,0xff,0xe0,0x8b,0x83,0xda,0xff,0xff,0xff,0xa2,0x00,0x10,0x0b,0x50,0x00,
    0x42,0x01,0x52,0xa3,0xe2,0x8f,0x01,0x06,0x50,0x00,0xb3,0x68,0xff,0xff,0x40,0x00,
    0x00,0x13,0xf1,0xff,0xff,0x8c,0x62,0x00,0x0a,0x02,0x00,0x05,0xf8,0x04,0x02,0xa9,
    0x05,0x04,0x1d,0x00,0x62,0xff,0x00,0x00,0x00,0x1d,0xca,0xdb,0x00,0x01,0x02,0x00,
    0x04,0x50,0x00,0xb4,0x41,0xa4,0xa4,0x12,0x00,0x00,0x00,0xc5,0xff,0xff,0xa8,0x2c,
    0x00,0x0f,0x02,0x00,0x07,0x09,0x50,0x00,0x11,0x0d,0xd8,0x01,0x48,0xe7,0xc1,0xb8,
    0xb8,0xa0,0x00,0x82,0x00,0x00,0x12,0x55,0x7a,0x8c,0x90,0xe4,0xe4,0x05,0x01,0x02,
    0x00,0x51,0x14,0x5e,0x7e,0x6c,0x1e,0x0a,0x00,0x0c,0x02,0x00,0x09,0x50,0x00,0x10,
    0x79,0x54,0x0a,0x23,0x79,0x03,0x3a,0x04,0x04,0xa0,0x00,0x31,0x01,0x81,0xf7,0xb0,
    0x00,0x06,0x50,0x00,0x7c,0x12,0xf7,0xfe,0xe1,0xfc,0xf9,0x42,0x4c,0x00,0x04,0x16,
    0x03,0x02,0x02,0x00,0x81,0xff,0x00,0x00,0xbb,0xff,0xff,0xff,0xd4,0x0e,0x00,0x08,
    0xa0,0x00,0x86,0x82,0xff,0xff,0xff,0xbc,0x8d,0x88,0xe2,0x50,0x00,0x71,0x13,0xff,
    0x7e,0x00,0x5d,0xff,0xb4,0x2a,0x00,0x0f,0x40,0x01,0x09,0xa7,0xd1,0xff,0xff,0xff,
    0xc8,0x00,0x00,0x00,0x00,0x2a,0x50,0x00,0x96,0x03,0xf3,0xff,0xff,0x8e,0x00,0x00,
    0x00,0xc0,0x50,0x00,0x73,0x02,0x22,0x49,0x61,0x84,0xff,0xcf,0x50,0x00,0x09,0x02,
    0x00,0x09,0xf0,0x00,0x10,0xb5,0x44,0x0b,0x50,0x70,0x18,0x1f,0x6c,0xec,0x4d,0x0b,
    0x12,0x94,0x29,0x00,0x96,0x19,0xff,0xff,0xff,0x56,0x00,0x00,0x03,0xd4,0x50,0x00,
    0x72,0x10,0xcc,0xff,0xde,0xd9,0xff,0xd0,0x20,0x00,0x0a,0x02,0x00,0x09,0x50,0x00,
    0x13,0x64,0x28,0x01,0x02,0x02,0x00,0xf2,0x05,0xfb,0xdc,0x4c,0x00,0x00,0x00,0x00,
    0x07,0xf7,0xff,0xff,0xd4,0x58,0x5f,0xc5,0xff,0xff,0xff,0xc1,0x1f,0x3d,0x00,0x55,
    0x6c,0xff,0xa4,0x00,0x30,0x50,0x00,0x0f,0x30,0x02,0x07,0x22,0x04,0xc2,0x4a,0x00,
    0x31,0xff,0xb3,0xc5,0x09,0x00,0x11,0x64,0x3f,0x00,0x11,0x95,0x0c,0x00,0x20,0xff,
    0xe1,0x01,0x0c,0x11,0x0c,0x12,0x00,0x81,0x64,0xff,0xd5,0x64,0xbe,0xff,0xdf,0x26,
    0x0d,0x00,0x0a,0x02,0x00,0x09,0xa0,0x00,0xb1,0x00,0x0a,0x92,0xf6,0xff,0xff,0xff,
    0xf3,0x83,0x05,0x72,0x44,0x00,0x02,0x50,0x00,0x86,0x07,0x97,0xfa,0xff,0xff,0xeb,
    0x5c,0x60,0x50,0x00,0x82,0x09,0xbc,0xff,0xfb,0x83,0xf9,0xff,0x9c,0x4b,0x00,0x0f,
    0xa0,0x00,0x07,0x7d,0x00,0x00,0x00,0x0a,0x3b,0x4e,0x3c,0xfa,0x04,0x41,0x0e,0x37,
    0x31,0x06,0x1e,0x00,0x05,0x02,0x00,0x25,0x14,0x0f,0x0b,0x00,0x0a,0x02,0x00,0x0a,
    0xa0,0x00,0x0f,0x02,0x00,0x2f,0x09,0x50,0x00,0x01,0xe5,0x00,0x0f,0x02,0x00,0x09,
    0xf2,0x0f,0xfb,0xf2,0xe9,0xe1,0xd9,0xd0,0xc7,0xbf,0xb6,0xae,0xa5,0x9d,0x94,0x8c,
    0x83,0x7a,0x71,0x69,0x60,0x58,0x4f,0x47,0x3e,0x36,0x2d,0x25,0x1c,0x13,0x0b,0x02,
    0x8d,0x02,0x04,0x94,0x00,0x0f,0xb0,0x09,0x00,0x0d,0x02,0x00,0x81,0xfb,0xf2,0xea,
    0xe1,0xd8,0xd0,0xc8,0xbe,0x50,0x00,0xbf,0x8b,0x83,0x7a,0x72,0x69,0x60,0x58,0x50,
    0x47,0x3e,0x35,0x50,0x00,0x27,0xa4,0xe9,0xe1,0xd8,0xd0,0xc7,0xbe,0xb6,0xad,0xa5,
    0x9c,0x50,0x00,0x01,0xa0,0x00,0x1f,0x24,0xa0,0x00,0x23,0x32,0xfa,0xf3,0xea,0x50,
    0x00,0x66,0xae,0xa5,0x9d,0x94,0x8b,0x82,0xa0,0x00,0x3f,0x24,0x1c,0x14,0xf0,0x00,
    0x27,0x03,0x40,0x01,0x03,0x50,0x00,0x1f,0x4f,0xf0,0x00,0x2a,0x01,0xa0,0x00,0x32,
    0xbf,0xb6,0xad,0x40,0x01,0x35,0x71,0x69,0x61,0x90,0x01,0x1f,0x0a,0x90,0x01,0x22,
    0x03,0xe0,0x01,0x87,0xad,0xa5,0x9d,0x94,0x8c,0x82,0x7a,0x72,0x50,0x00,0x0f,0xf0,
    0x00,0x23,0x57,0xe9,0xe1,0xd9,0xd0,0xc8,0x90,0x01,0x03,0xa0,0x00,0x5f,0x24,0x1c,
    0x14,0x0a,0x03,0x30,0x02,0x23,0x03,0x80,0x02,0x4f,0x9c,0x94,0x8c,0x83,0xa0,0x00,
    0x2e,0x61,0xfa,0xf2,0xea,0xe1,0xd9,0xcf,0x90,0x01,0x01,0x30,0x02,0x01,0x40,0x01,
    0x5f,0x46,0x3e,0x35,0x2d,0x24,0x40,0x01,0x23,0x18,0xfa,0x20,0x03,0x04,0xe0,0x01,
    0x21,0x46,0x3f,0x50,0x00,0x0f,0x40,0x01,0x25,0x01,0x30,0x02,0x41,0xad,0xa5,0x9d,
    0x93,0xf0,0x00,0x4f,0x60,0x58,0x50,0x46,0xd0,0x02,0x28,0x01,0x70,0x03,0x01,0xf0,
    0x00,0x01,0xc0,0x03,0x07,0x90,0x01,0x0f,0xc0,0x03,0x26,0x0a,0x90,0x01,0x51,0x60,
    0x57,0x50,0x47,0x3f,0xa0,0x00,0x0f,0x80,0x02,0x00,0x0f,0x02,0x00,0x30,0x09,0x60,
    0x04,0x0f,0x02,0x00,0x30,0x0f,0x50,0x00,0x48,0x0d,0xee,0x04,0x0f,0x02,0x00,0x22,
    0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

};

const lv_img_dsc_t test_A8_LZ4_align1 = {
  .header.magic = LV_IMAGE_HEADER_MAGIC,
  .header.cf = LV_COLOR_FORMAT_A8,
  .header.flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
  .header.w = 71,
  .header.h = 60,
  .header.stride = 80,
  .data_size = 1402,
  .data = test_A8_LZ4_align1_map,
};

==> buffybox_3.4.2+dfsg.orig.tar.xz: buffybox-3.4.2+dfsg/lvgl/tests/test_images/stride_align1/LZ4/test_A8_LZ4_align1.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_LVGL_H_INCLUDE_SYSTEM)
#include <lvgl.h>
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif

#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_TEST_A8_LZ4_ALIGN1
#define LV_ATTRIBUTE_TEST_A8_LZ4_ALIGN1
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_TEST_A8_LZ4_ALIGN1
uint8_t test_A8_LZ4_align1_map[] = {

    0x02,0x00,0x00,0x00,0x6e,0x05,0x00,0x00,0xc0,0x12,0x00,0x00,0x1f,0xff,0x01,0x00,
    0x33,0x14,0x00,0x01,0x00,0x14,0xff,0x09,0x00,0x0f,0x02,0x00,0x2a,0x06,0x46,0x00,
    0x06,0x0a,0x00,0x0f,0x02,0x00,0x29,0x06,0x46,0x00,0x3c,0xff,0x00,0x00,0xf2,0x00,
    0x0f,0x59,0x00,0x0d,0x0c,0x30,0x00,0x11,0xff,0x46,0x00,0x03,0x02,0x00,0x0f,0x50,
    0x00,0x07,0x83,0x3f,0x96,0xd6,0xf9,0xf9,0xd6,0x96,0x3f,0x29,0x00,0x06,0x02,0x00,
    0x06,0x8d,0x00,0x02,0x02,0x00,0x0f,0x50,0x00,0x12,0x24,0x1a,0x93,0x87,0x00,0x22,
    0x93,0x1a,0x37,0x00,0x41,0x6a,0xdf,0xdf,0x6a,0x0a,0x00,0x1a,0xff,0xd2,0x00,0x0f,
    0x50,0x00,0x12,0x24,0x1a,0xa7,0x4f,0x00,0x32,0xff,0xff,0xa7,0x51,0x00,0x44,0xdf,
    0xff,0xff,0xdf,0x50,0x00,0x01,0x08,0x00,0x02,0x02,0x00,0x0f,0x50,0x00,0x13,0x05,
    0x9e,0x00,0x00,0x50,0x02,0x11,0x93,0x3a,0x00,0x09,0x50,0x00,0x02,0x19,0x00,0x02,
    0x9e,0x00,0x0f,0xa0,0x00,0x10,0x11,0x3f,0x2c,0x00,0x05,0x02,0x00,0x01,0x44,0x01,
    0x08,0xf0,0x00,0x05,0xa2,0x00,0x03,0x0c,0x00,0x06,0x53,0x01,0x0f,0x90,0x01,0x03,
    0x15,0x96,0x4b,0x00,0x01,0x02,0x00,0x11,0x96,0xa1,0x00,0x04,0x02,0x00,0x02,0x44,
    0x00,0x01,0x19,0x00,0x01,0x4e,0x00,0x0f,0xa0,0x00,0x10,0x11,0xd6,0x2e,0x00,0x05,
    0x02,0x00,0x14,0xd6,0x4b,0x00,0x01,0x02,0x00,0x03,0x50,0x00,0x08,0x0a,0x00,0x0f,
    0xa0,0x00,0x0d,0x15,0xf9,0x4b,0x00,0x01,0x02,0x00,0xb7,0xf9,0x00,0x00,0x00,0x40,
    0xac,0xf2,0xf2,0xac,0x40,0x00,0x46,0x00,0x06,0x02,0x00,0x01,0x5d,0x00,0x02,0x02,
    0x00,0x0f,0xf0,0x00,0x03,0x0e,0x50,0x00,0x20,0x40,0xd3,0xea,0x03,0x27,0xd3,0x40,
    0x50,0x00,0x0f,0xa0,0x00,0x18,0x0e,0xf0,0x00,0x11,0xac,0xa9,0x00,0x26,0xff,0xac,
    0x50,0x00,0x00,0x4a,0x04,0x0f,0x40,0x01,0x15,0x0e,0x90,0x01,0x12,0xf2,0x50,0x00,
    0x15,0xf2,0x50,0x00,0x04,0xdf,0x00,0x0f,0x90,0x01,0x12,0x0e,0x30,0x02,0x0c,0x50,
    0x00,0x02,0x5f,0x00,0x03,0xa2,0x00,0x0f,0x40,0x01,0x0e,0x0e,0xd0,0x02,0x0b,0xf0,
    0x00,0x02,0x9e,0x00,0x04,0x9e,0x01,0x0f,0x50,0x00,0x0f,0x0d,0x70,0x03,0x0a,0x90,
    0x01,0x04,0x9e,0x00,0x03,0xa2,0x00,0x0f,0x50,0x00,0x0f,0x0e,0x10,0x04,0x08,0x30,
    0x02,0x02,0x9a,0x00,0x04,0x02,0x00,0x0c,0x50,0x00,0x0f,0x02,0x00,0x04,0x0f,0xb0,
    0x04,0x07,0x02,0x98,0x00,0x06,0x02,0x00,0x01,0x53,0x00,0x03,0x02,0x00,0x0c,0x6d,
    0x00,0x0f,0x02,0x00,0x23,0x06,0x46,0x00,0x06,0x0a,0x00,0x0f,0x02,0x00,0x29,0x06,
    0x46,0x00,0x04,0x0a,0x00,0x54,0x12,0x28,0x33,0x26,0x08,0x53,0x00,0x06,0xcb,0x00,
    0x0f,0x02,0x00,0x12,0x06,0x46,0x00,0x03,0x0a,0x00,0x30,0x35,0x95,0xdd,0x38,0x07,
    0x44,0xfa,0xc4,0x5c,0x01,0x53,0x00,0x0f,0x02,0x00,0x1b,0x04,0x96,0x00,0x02,0x0a,
    0x00,0x16,0xb2,0x86,0x00,0x2f,0xbb,0x0b,0x49,0x00,0x1b,0x03,0x02,0x00,0x0a,0x50,
    0x00,0x10,0xe9,0xd5,0x07,0x21,0xfe,0xfa,0x56,0x00,0x13,0xa9,0x22,0x00,0x0f,0x02,
    0x00,0x1b,0x0a,0x50,0x00,0x81,0xe5,0xff,0xff,0xe5,0x49,0x09,0x03,0x3c,0xf5,0x00,
    0x1f,0x2b,0x4a,0x00,0x1b,0x02,0x02,0x00,0x0a,0x50,0x00,0x90,0xe1,0xff,0xff,0xa3,
    0x00,0x00,0x00,0x00,0x44,0x7d,0x08,0x12,0x6f,0x22,0x00,0xa4,0x00,0x00,0x14,0x76,
    0xbb,0xdd,0xe6,0xd3,0x9e,0x37,0x10,0x00,0x0f,0x02,0x00,0x09,0x0a,0x50,0x00,0x90,
    0xbe,0xdc,0xdc,0x6b,0x00,0x00,0x00,0x00,0x09,0xcd,0x08,0x13,0x89,0x38,0x00,0x21,
    0x53,0xf8,0x00,0x01,0x33,0xff,0xfe,0x7b,0x11,0x00,0x0f,0x02,0x00,0x09,0x0a,0x50,
    0x00,0x02,0x02,0x00,0x30,0x0e,0x14,0x14,0x1d,0x09,0x12,0x90,0x0e,0x00,0xbf,0x00,
    0x6c,0xff,0xff,0xe0,0x8b,0x83,0xda,0xff,0xff,0xff,0xa2,0x00,0x10,0x0b,0x50,0x00,
    0x42,0x01,0x52,0xa3,0xe2,0x8f,0x01,0x06,0x50,0x00,0xb3,0x68,0xff,0xff,0x40,0x00,
    0x00,0x13,0xf1,0xff,0xff,0x8c,0x62,0x00,0x0a,0x02,0x00,0x05,0xf8,0x04,0x02,0xa9,
    0x05,0x04,0x1d,0x00,0x62,0xff,0x00,0x00,0x00,0x1d,0xca,0xdb,0x00,0x01,0x02,0x00,
    0x04,0x50,0x00,0xb4,0x41,0xa4,0xa4,0x12,0x00,0x00,0x00,0xc5,0xff,0xff,0xa8,0x2c,
    0x00,0x0f,0x02,0x00,0x07,0x09,0x50,0x00,0x11,0x0d,0xd8,0x01,0x48,0xe7,0xc1,0xb8,
    0xb8,0xa0,0x00,0x82,0x00,0x00,0x12,0x55,0x7a,0x8c,0x90,0xe4,0xe4,0x05,0x01,0x02,
    0x00,0x51,0x14,0x5e,0x7e,0x6c,0x1e,0x0a,0x00,0x0c,0x02,0x00,0x09,0x50,0x00,0x10,
    0x79,0x54,0x0a,0x23,0x79,0x03,0x3a,0x04,0x04,0xa0,0x00,0x31,0x01,0x81,0xf7,0xb0,
    0x00,0x06,0x50,0x00,0x7c,0x12,0xf7,0xfe,0xe1,0xfc,0xf9,0x42,0x4c,0x00,0x04,0x16,
    0x03,0x02,0x02,0x00,0x81,0xff,0x00,0x00,0xbb,0xff,0xff,0xff,0xd4,0x0e,0x00,0x08,
    0xa0,0x00,0x86,0x82,0xff,0xff,0xff,0xbc,0x8d,0x88,0xe2,0x50,0x00,0x71,0x13,0xff,
    0x7e,0x00,0x5d,0xff,0xb4,0x2a,0x00,0x0f,0x40,0x01,0x09,0xa7,0xd1,0xff,0xff,0xff,
    0xc8,0x00,0x00,0x00,0x00,0x2a,0x50,0x00,0x96,0x03,0xf3,0xff,0xff,0x8e,0x00,0x00,
    0x00,0xc0,0x50,0x00,0x73,0x02,0x22,0x49,0x61,0x84,0xff,0xcf,0x50,0x00,0x09,0x02,
    0x00,0x09,0xf0,0x00,0x10,0xb5,0x44,0x0b,0x50,0x70,0x18,0x1f,0x6c,0xec,0x4d,0x0b,
    0x12,0x94,0x29,0x00,0x96,0x19,0xff,0xff,0xff,0x56,0x00,0x00,0x03,0xd4,0x50,0x00,
    0x72,0x10,0xcc,0xff,0xde,0xd9,0xff,0xd0,0x20,0x00,0x0a,0x02,0x00,0x09,0x50,0x00,
    0x13,0x64,0x28,0x01,0x02,0x02,0x00,0xf2,0x05,0xfb,0xdc,0x4c,0x00,0x00,0x00,0x00,
    0x07,0xf7,0xff,0xff,0xd4,0x58,0x5f,0xc5,0xff,0xff,0xff,0xc1,0x1f,0x3d,0x00,0x55,
    0x6c,0xff,0xa4,0x00,0x30,0x50,0x00,0x0f,0x30,0x02,0x07,0x22,0x04,0xc2,0x4a,0x00,
    0x31,0xff,0xb3,0xc5,0x09,0x00,0x11,0x64,0x3f,0x00,0x11,0x95,0x0c,0x00,0x20,0xff,
    0xe1,0x01,0x0c,0x11,0x0c,0x12,0x00,0x81,0x64,0xff,0xd5,0x64,0xbe,0xff,0xdf,0x26,
    0x0d,0x00,0x0a,0x02,0x00,0x09,0xa0,0x00,0xb1,0x00,0x0a,0x92,0xf6,0xff,0xff,0xff,
    0xf3,0x83,0x05,0x72,0x44,0x00,0x02,0x50,0x00,0x86,0x07,0x97,0xfa,0xff,0xff,0xeb,
    0x5c,0x60,0x50,0x00,0x82,0x09,0xbc,0xff,0xfb,0x83,0xf9,0xff,0x9c,0x4b,0x00,0x0f,
    0xa0,0x00,0x07,0x7d,0x00,0x00,0x00,0x0a,0x3b,0x4e,0x3c,0xfa,0x04,0x41,0x0e,0x37,
    0x31,0x06,0x1e,0x00,0x05,0x02,0x00,0x25,0x14,0x0f,0x0b,0x00,0x0a,0x02,0x00,0x0a,
    0xa0,0x00,0x0f,0x02,0x00,0x2f,0x09,0x50,0x00,0x01,0xe5,0x00,0x0f,0x02,0x00,0x09,
    0xf2,0x0f,0xfb,0xf2,0xe9,0xe1,0xd9,0xd0,0xc7,0xbf,0xb6,0xae,0xa5,0x9d,0x94,0x8c,
    0x83,0x7a,0x71,0x69,0x60,0x58,0x4f,0x47,0x3e,0x36,0x2d,0x25,0x1c,0x13,0x0b,0x02,
    0x8d,0x02,0x04,0x94,0x00,0x0f,0xb0,0x09,0x00,0x0d,0x02,0x00,0x81,0xfb,0xf2,0xea,
    0xe1,0xd8,0xd0,0xc8,0xbe,0x50,0x00,0xbf,0x8b,0x83,0x7a,0x72,0x69,0x60,0x58,0x50,
    0x47,0x3e,0x35,0x50,0x00,0x27,0xa4,0xe9,0xe1,0xd8,0xd0,0xc7,0xbe,0xb6,0xad,0xa5,
    0x9c,0x50,0x00,0x01,0xa0,0x00,0x1f,0x24,0xa0,0x00,0x23,0x32,0xfa,0xf3,0xea,0x50,
    0x00,0x66,0xae,0xa5,0x9d,0x94,0x8b,0x82,0xa0,0x00,0x3f,0x24,0x1c,0x14,0xf0,0x00,
    0x27,0x03,0x40,0x01,0x03,0x50,0x00,0x1f,0x4f,0xf0,0x00,0x2a,0x01,0xa0,0x00,0x32,
    0xbf,0xb6,0xad,0x40,0x01,0x35,0x71,0x69,0x61,0x90,0x01,0x1f,0x0a,0x90,0x01,0x22,
    0x03,0xe0,0x01,0x87,0xad,0xa5,0x9d,0x94,0x8c,0x82,0x7a,0x72,0x50,0x00,0x0f,0xf0,
    0x00,0x23,0x57,0xe9,0xe1,0xd9,0xd0,0xc8,0x90,0x01,0x03,0xa0,0x00,0x5f,0x24,0x1c,
    0x14,0x0a,0x03,0x30,0x02,0x23,0x03,0x80,0x02,0x4f,0x9c,0x94,0x8c,0x83,0xa0,0x00,
    0x2e,0x61,0xfa,0xf2,0xea,0xe1,0xd9,0xcf,0x90,0x01,0x01,0x30,0x02,0x01,0x40,0x01,
    0x5f,0x46,0x3e,0x35,0x2d,0x24,0x40,0x01,0x23,0x18,0xfa,0x20,0x03,0x04,0xe0,0x01,
    0x21,0x46,0x3f,0x50,0x00,0x0f,0x40,0x01,0x25,0x01,0x30,0x02,0x41,0xad,0xa5,0x9d,
    0x93,0xf0,0x00,0x4f,0x60,0x58,0x50,0x46,0xd0,0x02,0x28,0x01,0x70,0x03,0x01,0xf0,
    0x00,0x01,0xc0,0x03,0x07,0x90,0x01,0x0f,0xc0,0x03,0x26,0x0a,0x90,0x01,0x51,0x60,
    0x57,0x50,0x47,0x3f,0xa0,0x00,0x0f,0x80,0x02,0x00,0x0f,0x02,0x00,0x30,0x09,0x60,
    0x04,0x0f,0x02,0x00,0x30,0x0f,0x50,0x00,0x48,0x0d,0xee,0x04,0x0f,0x02,0x00,0x22,
    0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

};

const lv_image_dsc_t test_A8_LZ4_align1 = {
  .header = {
    .magic = LV_IMAGE_HEADER_MAGIC,
    .cf = LV_COLOR_FORMAT_A8,
    .flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
    .w = 71,
    .h = 60,
    .stride = 80,
    .reserved_2 = 0,
  },
  .data_size = sizeof(test_A8_LZ4_align1_map),
  .data = test_A8_LZ4_align1_map,
  .reserved = NULL,
};
